In practice, the estimation result is just a couple of KHz
away from the kernel's tsc_khz value, so it should suffice.

Roundin to 10MHz can cause a significant drift from real time,
up to a second per 10 minutes.

See also bugzilla: 959

Signed-off-by: Isaac Boukris <ibouk...@gmail.com>
---
 lib/eal/linux/eal_timer.c | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/lib/eal/linux/eal_timer.c b/lib/eal/linux/eal_timer.c
index 1cb1e92193..241b20d416 100644
--- a/lib/eal/linux/eal_timer.c
+++ b/lib/eal/linux/eal_timer.c
@@ -192,7 +192,7 @@ get_tsc_freq(void)
 {
 #ifdef CLOCK_MONOTONIC_RAW
 #define NS_PER_SEC 1E9
-#define CYC_PER_10MHZ 1E7
+#define CYC_PER_10KHZ 1E4
 
        struct timespec sleeptime = {.tv_nsec = NS_PER_SEC / 10 }; /* 1/10 
second */
 
@@ -209,8 +209,8 @@ get_tsc_freq(void)
 
                double secs = (double)ns/NS_PER_SEC;
                tsc_hz = (uint64_t)((end - start)/secs);
-               /* Round up to 10Mhz. 1E7 ~ 10Mhz */
-               return RTE_ALIGN_MUL_NEAR(tsc_hz, CYC_PER_10MHZ);
+               /* Round up to 10Khz. 1E4 ~ 10Khz */
+               return RTE_ALIGN_MUL_NEAR(tsc_hz, CYC_PER_10KHZ);
        }
 #endif
        return 0;
-- 
2.45.0

Reply via email to